@@ -104,7 +104,25 @@ def csvImporter(csv_folder, csv_folder_encoding, csv_folder_cleaned, db_table_na
 
         # commonPreprocess(dataframe)
         stackTodb(dataframe, db_table_name)
+        
 
+def addPoolColumn(dataframe, keyword_pool):
+
+    pool = keywordPool(keyword_pool)
+    title_mapping = titleSummaryMaker(keyword_pool)
+
+    #키워드 풀에서 검색 후 포함되는 문자열은 리스트로 반환
+    dataframe['title_summary_temp'] = dataframe.apply(lambda x: [i for i in pool.get(x['brand'], []) if i in x['title']], axis=1)
+    dataframe['title_summary_temp'] = dataframe['title_summary_temp'].apply(lambda x: x if len(x) > 0 else '')
+
+    #리스트 안에서 문자열이 가장 긴 값 리턴
+    dataframe['title_summary_temp'] = dataframe['title_summary_temp'].apply(lambda x: max(x, key=lambda y: len(y)) if x else '')
+
+    #키워드 분류로 한번 더 매핑
+    final_df = pd.merge(dataframe, title_mapping, how='left', on='title_summary_temp')
+
+    return final_df
+    
 
 def csvImporter_NEW(csv_folder, csv_folder_cleaned, csv_folder_encoding, keyword_pool):
     column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
@@ -128,68 +146,70 @@ def csvImporter_NEW(csv_folder, csv_folder_cleaned, csv_folder_encoding, keyword
         # csv 파일 내 브랜드, 타이틀명 소문자 변경
         dataframe['brand'] = dataframe['brand'].str.lower()
         dataframe['title'] = dataframe['title'].str.lower()
-        
+
         ##### no pool
         if "Laptops" in fileList[i]:
             db_table_name = 'tb_stackline_laptops'
             # commonPreprocess(dataframe)
-            print("Pool 검색 안함")
             stackTodb(dataframe, db_table_name)
 
         if "Earbud" in fileList[i]:
             db_table_name = 'tb_stackline_earbuds'
             # commonPreprocess(dataframe)
-            print("Pool 검색 안함")
             stackTodb(dataframe, db_table_name)
 
         ##### pool
         if "Watches" in fileList[i]:
             db_table_name = 'tb_stackline_watches'
-            print("Pool 검색 시작")
-
-            #키워드 풀에서 검색 후 포함되는 문자열은 리스트로 반환
-            dataframe['title_summary_temp'] = dataframe.apply(lambda x: [i for i in pool.get(x['brand'], []) if i in x['title']], axis=1)
-            dataframe['title_summary_temp'] = dataframe['title_summary_temp'].apply(lambda x: x if len(x) > 0 else '')
-
-            #리스트 안에서 문자열이 가장 긴 값 리턴
-            dataframe['title_summary_temp'] = dataframe['title_summary_temp'].apply(lambda x: max(x, key=lambda y: len(y)) if x else '')
-
-            #키워드 분류로 한번 더 매핑
-            final_df = pd.merge(dataframe, title_mapping, how='left', on='title_summary_temp')
-
-            stackTodb(final_df, db_table_name)
+            stackTodb(addPoolColumn(db_table_name), db_table_name)
 
         if "Tablets" in fileList[i]:
             db_table_name = 'tb_stackline_tablets'
-            print("Pool 검색 시작")
-
-            #키워드 풀에서 검색 후 포함되는 문자열은 리스트로 반환
-            dataframe['title_summary_temp'] = dataframe.apply(lambda x: [i for i in pool.get(x['brand'], []) if i in x['title']], axis=1)
-            dataframe['title_summary_temp'] = dataframe['title_summary_temp'].apply(lambda x: x if len(x) > 0 else '')
-
-            #리스트 안에서 문자열이 가장 긴 값 리턴
-            dataframe['title_summary_temp'] = dataframe['title_summary_temp'].apply(lambda x: max(x, key=lambda y: len(y)) if x else '')
-
-            #키워드 분류로 한번 더 매핑
-            final_df = pd.merge(dataframe, title_mapping, how='left', on='title_summary_temp')
-
-            stackTodb(final_df, db_table_name)
+            stackTodb(addPoolColumn(db_table_name), db_table_name)
 
         if "Phones" in fileList[i]:
             db_table_name = 'tb_stackline_smartphones'
-            print("Pool 검색 시작")
+            stackTodb(addPoolColumn(db_table_name), db_table_name)
 
-            #키워드 풀에서 검색 후 포함되는 문자열은 리스트로 반환
-            dataframe['title_summary_temp'] = dataframe.apply(lambda x: [i for i in pool.get(x['brand'], []) if i in x['title']], axis=1)
-            dataframe['title_summary_temp'] = dataframe['title_summary_temp'].apply(lambda x: x if len(x) > 0 else '')
 
-            #리스트 안에서 문자열이 가장 긴 값 리턴
-            dataframe['title_summary_temp'] = dataframe['title_summary_temp'].apply(lambda x: max(x, key=lambda y: len(y)) if x else '')
+def keywordCheck(csv_folder, csv_folder_cleaned, csv_folder_encoding, pool_check_folder, keyword_pool):
+    column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
+    # csv 줄밀림 정제
+    csvEncoder(csv_folder, csv_folder_encoding)
+    csvCleaner(csv_folder_cleaned, csv_folder_encoding)
 
-            #키워드 분류로 한번 더 매핑
-            final_df = pd.merge(dataframe, title_mapping, how='left', on='title_summary_temp')
+    # 키워드 풀 가져오기
+    pool = keywordPool(keyword_pool)
+    title_mapping = titleSummaryMaker(keyword_pool)
+
+    fileList = os.listdir(csv_folder_cleaned)
+    for i in range(len(fileList)):
+        dataframe = pd.read_csv(csv_folder_cleaned + "\\" + fileList[i], sep=',', engine='c', encoding='latin-1')
+        dataframe.columns = column_name
+        
+        #파일명 제일 앞단에 삽입
+        dataframe.insert(0, "file_name", fileList[i][:-4], True)
+
+        # csv 파일 내 브랜드, 타이틀명 소문자 변경
+        dataframe['brand'] = dataframe['brand'].str.lower()
+        dataframe['title'] = dataframe['title'].str.lower()
+
+        # sales unit / retail sales 컬럼 추가
+        check_frame = dataframe[['brand', 'title', 'units_sold', 'retail_sales']].groupby(by=['brand', 'title'], as_index=False).sum()
+
+        # 키워드 풀과 겹치는 스트링 반환 
+        check_frame['title_summary_list'] = check_frame.apply(lambda x: [i for i in pool.get(x['brand'], []) if i in x['title']], axis=1)
+        check_frame['title_summary_list'] = check_frame['title_summary_list'].apply(lambda x: x if len(x) > 0 else '')
+             
+        # 리스트 중 가장 문자열이 긴 값 리턴
+        check_frame['title_summary_temp'] = check_frame['title_summary_list'].apply(lambda x: max(x, key=lambda y: len(y)) if x else '')
+        
+        #키워드 분류로 한번 더 매핑
+        final_df = pd.merge(dataframe, title_mapping, how='left', on='title_summary_temp')
+
+        #pool 폴더로 검수용 파일 반환
+        final_df.to_csv(pool_check_folder + "\\Keyword_Check" + fileList[i], sep=',', na_rep='', encoding='utf-8-sig', index = False)
 
-            stackTodb(final_df, db_table_name)
 
 # if __name__ == "__main__":
 # #     db_table_name = 'tb_stackline_dataset'
